Welcome!
========

Kubify OS, Version: 9005.0.11

Well hello there! Welcome to Kubify. 

The Turn-Key DevOps/MLOps OS Developer-First Stack.


Who is this for?
================

Data Scientists/Devs/DevOps/MLOps Person/Teams/Companies who want self service and autopilot DevEx to code faster.

To rapid develop many services/models fast simultaneously on full real
environment.

1. Automated Self-Service Clouds and Services.
2. Automated DR. Automatic Multi-Cloud Failover.
3. Rapid Test/Develop many Services/Models Simultaneously.
4. Full Automated Integration Test. Stable Prod.

Turn Key DevOps/MLOps DR-Enabled Scalable Lowest-Cost Full Rapid Testing Stack. 

Ideoligy: If it works on your laptop/test/notebook, it works in prod.


How?
====

DevEx First Class Ideology

.. figure:: ./docs/img/README_md_imgs/the-future.gif
   :alt: FUTUREOFDEVOPS9000

Contributing:

(choose any to contribute to the kubify python package in this repo)
A. devcontainer or container
B. ``tox``
C. ``make docker``
D. ``make pip``
E. ``make pythons``
F. ``make test``
G. and more ..

Happy Coding!

.. figure:: ./docs/img/README_md_imgs/level-up.gif
   :alt: FUTUREOFDEVOPS9001

.. |Docker| image:: https://github.com/willyguggenheim/kubify/actions/workflows/docker-image.yml/badge.svg?branch=main
   :target: https://github.com/willyguggenheim/kubify/actions/workflows/docker-image.yml
.. |PyPi| image:: https://img.shields.io/pypi/v/kubify.svg
   :target: https://pypi.python.org/pypi/kubify
.. |PyUp| image:: https://pyup.io/repos/github/willyguggenheim/kubify/shield.svg
   :target: https://pyup.io/repos/github/willyguggenheim/kubify/
.. |Docs| image:: https://readthedocs.org/projects/kubify/badge/?version=latest
   :target: hhttps://kubify.readthedocs.io/en/latest/?version=latest

.. figure:: ./docs/img/README_md_imgs/kubify-arch.drawio.png
   :alt: TURN_KEY_DEVOPS_RAPID_TESTER

AWS Loves Kubify.

.. figure:: ./docs/img/README_md_imgs/AWS-Partner.jpeg
   :alt: AWSPARTNER

Turn Key Automated/Autopilot MLOps/DevOps OS Stack.

On-Boarding Steps.

1. ``make clouds``
2. ``kubfiy start-all``